@@ -7,17 +7,12 @@ import (
 	"database/sql"
 	"errors"
 	"fmt"
+	"strings"
 
 	"github.com/lib/pq"
 	"github.com/xataio/pgroll/pkg/schema"
 )
 
-type OpAddColumn struct {
-	Table  string  `json:"table"`
-	Up     *string `json:"up"`
-	Column Column  `json:"column"`
-}
-
 var _ Operation = (*OpAddColumn)(nil)
 
 func (o *OpAddColumn) Start(ctx context.Context, conn *sql.DB, stateSchema string, s *schema.Schema, cbs ...CallbackFn) error {
@@ -27,7 +22,13 @@ func (o *OpAddColumn) Start(ctx context.Context, conn *sql.DB, stateSchema strin
 		return fmt.Errorf("failed to start add column operation: %w", err)
 	}
 
-	if !o.Column.Nullable && o.Column.Default == nil {
+	if o.Column.Comment != nil {
+		if err := addCommentToColumn(ctx, conn, o.Table, TemporaryName(o.Column.Name), *o.Column.Comment); err != nil {
+			return fmt.Errorf("failed to add comment to column: %w", err)
+		}
+	}
+
+	if !o.Column.IsNullable() && o.Column.Default == nil {
 		if err := addNotNullConstraint(ctx, conn, o.Table, o.Column.Name, TemporaryName(o.Column.Name)); err != nil {
 			return fmt.Errorf("failed to add not null constraint: %w", err)
 		}
@@ -65,7 +66,7 @@ func (o *OpAddColumn) Start(ctx context.Context, conn *sql.DB, stateSchema strin
 	return nil
 }
 
-func (o *OpAddColumn) Complete(ctx context.Context, conn *sql.DB) error {
+func (o *OpAddColumn) Complete(ctx context.Context, conn *sql.DB, s *schema.Schema) error {
 	tempName := TemporaryName(o.Column.Name)
 
 	_, err := conn.ExecContext(ctx, fmt.Sprintf("ALTER TABLE IF EXISTS %s RENAME COLUMN %s TO %s",
@@ -83,7 +84,7 @@ func (o *OpAddColumn) Complete(ctx context.Context, conn *sql.DB) error {
 		return err
 	}
 
-	if !o.Column.Nullable && o.Column.Default == nil {
+	if !o.Column.IsNullable() && o.Column.Default == nil {
 		_, err = conn.ExecContext(ctx, fmt.Sprintf("ALTER TABLE IF EXISTS %s VALIDATE CONSTRAINT %s",
 			pq.QuoteIdentifier(o.Table),
 			pq.QuoteIdentifier(NotNullConstraintName(o.Column.Name))))
@@ -169,11 +170,11 @@ func (o *OpAddColumn) Validate(ctx context.Context, s *schema.Schema) error {
 		return InvalidPrimaryKeyError{Table: o.Table, Fields: len(pk)}
 	}
 
-	if !o.Column.Nullable && o.Column.Default == nil && o.Up == nil {
+	if !o.Column.IsNullable() && o.Column.Default == nil && o.Up == nil {
 		return FieldRequiredError{Name: "up"}
 	}
 
-	if o.Column.PrimaryKey {
+	if o.Column.IsPrimaryKey() {
 		return errors.New("adding primary key columns is not supported")
 	}
 
@@ -188,8 +189,8 @@ func addColumn(ctx context.Context, conn *sql.DB, o OpAddColumn, t *schema.Table
 	// - validating the constraint and converting the column to not null
 	//   on migration completion
 	// This is to avoid unnecessary exclusive table locks.
-	if !o.Column.Nullable && o.Column.Default == nil {
-		o.Column.Nullable = true
+	if !o.Column.IsNullable() && o.Column.Default == nil {
+		o.Column.Nullable = ptr(true)
 	}
 
 	// Don't add a column with a CHECK constraint directly.
@@ -227,5 +228,9 @@ func (o *OpAddColumn) addCheckConstraint(ctx context.Context, conn *sql.DB) erro
 }
 
 func NotNullConstraintName(columnName string) string {
-	return "_pgroll_add_column_check_" + columnName
+	return "_pgroll_check_not_null_" + columnName
+}
+
+func IsNotNullConstraintName(name string) bool {
+	return strings.HasPrefix(name, "_pgroll_check_not_null_")
 }
