@@ -9,6 +9,7 @@ import (
 	"github.com/stretchr/testify/assert"
 
 	"github.com/xataio/pgroll/pkg/migrations"
+	"github.com/xataio/pgroll/pkg/testutils"
 )
 
 func TestAddColumn(t *testing.T) {
@@ -24,14 +25,14 @@ func TestAddColumn(t *testing.T) {
 						Name: "users",
 						Columns: []migrations.Column{
 							{
-								Name:       "id",
-								Type:       "serial",
-								PrimaryKey: true,
+								Name: "id",
+								Type: "serial",
+								Pk:   ptr(true),
 							},
 							{
 								Name:   "name",
 								Type:   "varchar(255)",
-								Unique: true,
+								Unique: ptr(true),
 							},
 						},
 					},
@@ -45,59 +46,60 @@ func TestAddColumn(t *testing.T) {
 						Column: migrations.Column{
 							Name:     "age",
 							Type:     "integer",
-							Nullable: false,
+							Nullable: ptr(false),
 							Default:  ptr("0"),
+							Comment:  ptr("the age of the user"),
 						},
 					},
 				},
 			},
 		},
-		afterStart: func(t *testing.T, db *sql.DB) {
+		afterStart: func(t *testing.T, db *sql.DB, schema string) {
 			// old and new views of the table should exist
-			ViewMustExist(t, db, "public", "01_add_table", "users")
-			ViewMustExist(t, db, "public", "02_add_column", "users")
+			ViewMustExist(t, db, schema, "01_add_table", "users")
+			ViewMustExist(t, db, schema, "02_add_column", "users")
 
 			// inserting via both the old and the new views works
-			MustInsert(t, db, "public", "01_add_table", "users", map[string]string{
+			MustInsert(t, db, schema, "01_add_table", "users", map[string]string{
 				"name": "Alice",
 			})
-			MustInsert(t, db, "public", "02_add_column", "users", map[string]string{
+			MustInsert(t, db, schema, "02_add_column", "users", map[string]string{
 				"name": "Bob",
 				"age":  "21",
 			})
 
 			// selecting from both the old and the new views works
-			resOld := MustSelect(t, db, "public", "01_add_table", "users")
+			resOld := MustSelect(t, db, schema, "01_add_table", "users")
 			assert.Equal(t, []map[string]any{
 				{"id": 1, "name": "Alice"},
 				{"id": 2, "name": "Bob"},
 			}, resOld)
-			resNew := MustSelect(t, db, "public", "02_add_column", "users")
+			resNew := MustSelect(t, db, schema, "02_add_column", "users")
 			assert.Equal(t, []map[string]any{
 				{"id": 1, "name": "Alice", "age": 0},
 				{"id": 2, "name": "Bob", "age": 21},
 			}, resNew)
 		},
-		afterRollback: func(t *testing.T, db *sql.DB) {
+		afterRollback: func(t *testing.T, db *sql.DB, schema string) {
 			// The new column has been dropped from the underlying table
 			columnName := migrations.TemporaryName("age")
-			ColumnMustNotExist(t, db, "public", "users", columnName)
+			ColumnMustNotExist(t, db, schema, "users", columnName)
 
 			// The table's column count reflects the drop of the new column
-			TableMustHaveColumnCount(t, db, "public", "users", 2)
+			TableMustHaveColumnCount(t, db, schema, "users", 2)
 		},
-		afterComplete: func(t *testing.T, db *sql.DB) {
+		afterComplete: func(t *testing.T, db *sql.DB, schema string) {
 			// The new view still exists
-			ViewMustExist(t, db, "public", "02_add_column", "users")
+			ViewMustExist(t, db, schema, "02_add_column", "users")
 
 			// Inserting into the new view still works
-			MustInsert(t, db, "public", "02_add_column", "users", map[string]string{
+			MustInsert(t, db, schema, "02_add_column", "users", map[string]string{
 				"name": "Carl",
 				"age":  "31",
 			})
 
 			// Selecting from the new view still works
-			res := MustSelect(t, db, "public", "02_add_column", "users")
+			res := MustSelect(t, db, schema, "02_add_column", "users")
 			assert.Equal(t, []map[string]any{
 				{"id": 1, "name": "Alice", "age": 0},
 				{"id": 2, "name": "Bob", "age": 0},
@@ -121,14 +123,14 @@ func TestAddForeignKeyColumn(t *testing.T) {
 							Name: "users",
 							Columns: []migrations.Column{
 								{
-									Name:       "id",
-									Type:       "serial",
-									PrimaryKey: true,
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
 								},
 								{
 									Name:   "name",
 									Type:   "varchar(255)",
-									Unique: true,
+									Unique: ptr(true),
 								},
 							},
 						},
@@ -136,9 +138,9 @@ func TestAddForeignKeyColumn(t *testing.T) {
 							Name: "orders",
 							Columns: []migrations.Column{
 								{
-									Name:       "id",
-									Type:       "serial",
-									PrimaryKey: true,
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
 								},
 								{
 									Name: "quantity",
@@ -161,56 +163,56 @@ func TestAddForeignKeyColumn(t *testing.T) {
 									Table:  "users",
 									Column: "id",
 								},
-								Nullable: true,
+								Nullable: ptr(true),
 							},
 						},
 					},
 				},
 			},
-			afterStart: func(t *testing.T, db *sql.DB) {
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
 				// The foreign key constraint exists on the new table.
-				ConstraintMustExist(t, db, "public", "orders", "fk_users_id")
+				ValidatedForeignKeyMustExist(t, db, schema, "orders", "fk_users_id")
 
 				// Inserting a row into the referenced table succeeds.
-				MustInsert(t, db, "public", "01_create_table", "users", map[string]string{
+				MustInsert(t, db, schema, "01_create_table", "users", map[string]string{
 					"name": "alice",
 				})
 
 				// Inserting a row into the referencing table succeeds as the referenced row exists.
-				MustInsert(t, db, "public", "02_add_column", "orders", map[string]string{
+				MustInsert(t, db, schema, "02_add_column", "orders", map[string]string{
 					"user_id":  "1",
 					"quantity": "100",
 				})
 
 				// Inserting a row into the referencing table fails as the referenced row does not exist.
-				MustNotInsert(t, db, "public", "02_create_table_with_fk", "orders", map[string]string{
+				MustNotInsert(t, db, schema, "02_add_column", "orders", map[string]string{
 					"user_id":  "2",
 					"quantity": "200",
-				})
+				}, testutils.FKViolationErrorCode)
 			},
-			afterRollback: func(t *testing.T, db *sql.DB) {
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
 				// The new column has been dropped, so the foreign key constraint is gone.
 			},
-			afterComplete: func(t *testing.T, db *sql.DB) {
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
 				// The foreign key constraint still exists on the new table
-				ConstraintMustExist(t, db, "public", "orders", "fk_users_id")
+				ValidatedForeignKeyMustExist(t, db, schema, "orders", "fk_users_id")
 
 				// Inserting a row into the referenced table succeeds.
-				MustInsert(t, db, "public", "02_add_column", "users", map[string]string{
+				MustInsert(t, db, schema, "02_add_column", "users", map[string]string{
 					"name": "bob",
 				})
 
 				// Inserting a row into the referencing table succeeds as the referenced row exists.
-				MustInsert(t, db, "public", "02_add_column", "orders", map[string]string{
+				MustInsert(t, db, schema, "02_add_column", "orders", map[string]string{
 					"user_id":  "2",
 					"quantity": "200",
 				})
 
 				// Inserting a row into the referencing table fails as the referenced row does not exist.
-				MustNotInsert(t, db, "public", "02_add_column", "orders", map[string]string{
+				MustNotInsert(t, db, schema, "02_add_column", "orders", map[string]string{
 					"user_id":  "3",
 					"quantity": "300",
-				})
+				}, testutils.FKViolationErrorCode)
 			},
 		},
 		{
@@ -223,14 +225,14 @@ func TestAddForeignKeyColumn(t *testing.T) {
 							Name: "users",
 							Columns: []migrations.Column{
 								{
-									Name:       "id",
-									Type:       "serial",
-									PrimaryKey: true,
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
 								},
 								{
 									Name:   "name",
 									Type:   "varchar(255)",
-									Unique: true,
+									Unique: ptr(true),
 								},
 							},
 						},
@@ -238,9 +240,9 @@ func TestAddForeignKeyColumn(t *testing.T) {
 							Name: "orders",
 							Columns: []migrations.Column{
 								{
-									Name:       "id",
-									Type:       "serial",
-									PrimaryKey: true,
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
 								},
 								{
 									Name: "quantity",
@@ -263,57 +265,57 @@ func TestAddForeignKeyColumn(t *testing.T) {
 									Table:  "users",
 									Column: "id",
 								},
-								Nullable: false,
+								Nullable: ptr(false),
 							},
 							Up: ptr("1"),
 						},
 					},
 				},
 			},
-			afterStart: func(t *testing.T, db *sql.DB) {
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
 				// The foreign key constraint exists on the new table.
-				ConstraintMustExist(t, db, "public", "orders", "fk_users_id")
+				ValidatedForeignKeyMustExist(t, db, schema, "orders", "fk_users_id")
 
 				// Inserting a row into the referenced table succeeds.
-				MustInsert(t, db, "public", "01_create_table", "users", map[string]string{
+				MustInsert(t, db, schema, "01_create_table", "users", map[string]string{
 					"name": "alice",
 				})
 
 				// Inserting a row into the referencing table succeeds as the referenced row exists.
-				MustInsert(t, db, "public", "02_add_column", "orders", map[string]string{
+				MustInsert(t, db, schema, "02_add_column", "orders", map[string]string{
 					"user_id":  "1",
 					"quantity": "100",
 				})
 
 				// Inserting a row into the referencing table fails as the referenced row does not exist.
-				MustNotInsert(t, db, "public", "02_create_table_with_fk", "orders", map[string]string{
+				MustNotInsert(t, db, schema, "02_add_column", "orders", map[string]string{
 					"user_id":  "2",
 					"quantity": "200",
-				})
+				}, testutils.FKViolationErrorCode)
 			},
-			afterRollback: func(t *testing.T, db *sql.DB) {
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
 				// The new column has been dropped, so the foreign key constraint is gone.
 			},
-			afterComplete: func(t *testing.T, db *sql.DB) {
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
 				// The foreign key constraint still exists on the new table
-				ConstraintMustExist(t, db, "public", "orders", "fk_users_id")
+				ValidatedForeignKeyMustExist(t, db, schema, "orders", "fk_users_id")
 
 				// Inserting a row into the referenced table succeeds.
-				MustInsert(t, db, "public", "02_add_column", "users", map[string]string{
+				MustInsert(t, db, schema, "02_add_column", "users", map[string]string{
 					"name": "bob",
 				})
 
 				// Inserting a row into the referencing table succeeds as the referenced row exists.
-				MustInsert(t, db, "public", "02_add_column", "orders", map[string]string{
+				MustInsert(t, db, schema, "02_add_column", "orders", map[string]string{
 					"user_id":  "2",
 					"quantity": "200",
 				})
 
 				// Inserting a row into the referencing table fails as the referenced row does not exist.
-				MustNotInsert(t, db, "public", "02_add_column", "orders", map[string]string{
+				MustNotInsert(t, db, schema, "02_add_column", "orders", map[string]string{
 					"user_id":  "3",
 					"quantity": "300",
-				})
+				}, testutils.FKViolationErrorCode)
 			},
 		},
 	})
@@ -322,88 +324,174 @@ func TestAddForeignKeyColumn(t *testing.T) {
 func TestAddColumnWithUpSql(t *testing.T) {
 	t.Parallel()
 
-	ExecuteTests(t, TestCases{{
-		name: "add column with up sql",
-		migrations: []migrations.Migration{
-			{
-				Name: "01_add_table",
-				Operations: migrations.Operations{
-					&migrations.OpCreateTable{
-						Name: "products",
-						Columns: []migrations.Column{
-							{
-								Name:       "id",
-								Type:       "serial",
-								PrimaryKey: true,
+	ExecuteTests(t, TestCases{
+		{
+			name: "add column with up sql and a serial pk",
+			migrations: []migrations.Migration{
+				{
+					Name: "01_add_table",
+					Operations: migrations.Operations{
+						&migrations.OpCreateTable{
+							Name: "products",
+							Columns: []migrations.Column{
+								{
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
+								},
+								{
+									Name:   "name",
+									Type:   "varchar(255)",
+									Unique: ptr(true),
+								},
 							},
-							{
-								Name:   "name",
-								Type:   "varchar(255)",
-								Unique: true,
+						},
+					},
+				},
+				{
+					Name: "02_add_column",
+					Operations: migrations.Operations{
+						&migrations.OpAddColumn{
+							Table: "products",
+							Up:    ptr("UPPER(name)"),
+							Column: migrations.Column{
+								Name:     "description",
+								Type:     "varchar(255)",
+								Nullable: ptr(true),
 							},
 						},
 					},
 				},
 			},
-			{
-				Name: "02_add_column",
-				Operations: migrations.Operations{
-					&migrations.OpAddColumn{
-						Table: "products",
-						Up:    ptr("UPPER(name)"),
-						Column: migrations.Column{
-							Name:     "description",
-							Type:     "varchar(255)",
-							Nullable: true,
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
+				// inserting via both the old and the new views works
+				MustInsert(t, db, schema, "01_add_table", "products", map[string]string{
+					"name": "apple",
+				})
+				MustInsert(t, db, schema, "02_add_column", "products", map[string]string{
+					"name":        "banana",
+					"description": "a yellow banana",
+				})
+
+				res := MustSelect(t, db, schema, "02_add_column", "products")
+				assert.Equal(t, []map[string]any{
+					// the description column has been populated for the product inserted into the old view.
+					{"id": 1, "name": "apple", "description": "APPLE"},
+					// the description column for the product inserted into the new view is as inserted.
+					{"id": 2, "name": "banana", "description": "a yellow banana"},
+				}, res)
+			},
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+				// The trigger function has been dropped.
+				triggerFnName := migrations.TriggerFunctionName("products", "description")
+				FunctionMustNotExist(t, db, schema, triggerFnName)
+
+				// The trigger has been dropped.
+				triggerName := migrations.TriggerName("products", "description")
+				TriggerMustNotExist(t, db, schema, "products", triggerName)
+			},
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+				// after rollback + restart + complete, all 'description' values are the backfilled ones.
+				res := MustSelect(t, db, schema, "02_add_column", "products")
+				assert.Equal(t, []map[string]any{
+					{"id": 1, "name": "apple", "description": "APPLE"},
+					{"id": 2, "name": "banana", "description": "BANANA"},
+				}, res)
+
+				// The trigger function has been dropped.
+				triggerFnName := migrations.TriggerFunctionName("products", "description")
+				FunctionMustNotExist(t, db, schema, triggerFnName)
+
+				// The trigger has been dropped.
+				triggerName := migrations.TriggerName("products", "description")
+				TriggerMustNotExist(t, db, schema, "products", triggerName)
+			},
+		},
+		{
+			name: "add column with up sql and a text pk",
+			migrations: []migrations.Migration{
+				{
+					Name: "01_add_table",
+					Operations: migrations.Operations{
+						&migrations.OpCreateTable{
+							Name: "products",
+							Columns: []migrations.Column{
+								{
+									Name: "id",
+									Type: "text",
+									Pk:   ptr(true),
+								},
+								{
+									Name:   "name",
+									Type:   "varchar(255)",
+									Unique: ptr(true),
+								},
+							},
+						},
+					},
+				},
+				{
+					Name: "02_add_column",
+					Operations: migrations.Operations{
+						&migrations.OpAddColumn{
+							Table: "products",
+							Up:    ptr("UPPER(name)"),
+							Column: migrations.Column{
+								Name:     "description",
+								Type:     "varchar(255)",
+								Nullable: ptr(true),
+							},
 						},
 					},
 				},
 			},
-		},
-		afterStart: func(t *testing.T, db *sql.DB) {
-			// inserting via both the old and the new views works
-			MustInsert(t, db, "public", "01_add_table", "products", map[string]string{
-				"name": "apple",
-			})
-			MustInsert(t, db, "public", "02_add_column", "products", map[string]string{
-				"name":        "banana",
-				"description": "a yellow banana",
-			})
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
+				// inserting via both the old and the new views works
+				MustInsert(t, db, schema, "01_add_table", "products", map[string]string{
+					"id":   "a",
+					"name": "apple",
+				})
+				MustInsert(t, db, schema, "02_add_column", "products", map[string]string{
+					"id":          "b",
+					"name":        "banana",
+					"description": "a yellow banana",
+				})
 
-			res := MustSelect(t, db, "public", "02_add_column", "products")
-			assert.Equal(t, []map[string]any{
-				// the description column has been populated for the product inserted into the old view.
-				{"id": 1, "name": "apple", "description": "APPLE"},
-				// the description column for the product inserted into the new view is as inserted.
-				{"id": 2, "name": "banana", "description": "a yellow banana"},
-			}, res)
-		},
-		afterRollback: func(t *testing.T, db *sql.DB) {
-			// The trigger function has been dropped.
-			triggerFnName := migrations.TriggerFunctionName("products", "description")
-			FunctionMustNotExist(t, db, "public", triggerFnName)
+				res := MustSelect(t, db, schema, "02_add_column", "products")
+				assert.Equal(t, []map[string]any{
+					// the description column has been populated for the product inserted into the old view.
+					{"id": "a", "name": "apple", "description": "APPLE"},
+					// the description column for the product inserted into the new view is as inserted.
+					{"id": "b", "name": "banana", "description": "a yellow banana"},
+				}, res)
+			},
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+				// The trigger function has been dropped.
+				triggerFnName := migrations.TriggerFunctionName("products", "description")
+				FunctionMustNotExist(t, db, schema, triggerFnName)
 
-			// The trigger has been dropped.
-			triggerName := migrations.TriggerName("products", "description")
-			TriggerMustNotExist(t, db, "public", "products", triggerName)
-		},
-		afterComplete: func(t *testing.T, db *sql.DB) {
-			// after rollback + restart + complete, all 'description' values are the backfilled ones.
-			res := MustSelect(t, db, "public", "02_add_column", "products")
-			assert.Equal(t, []map[string]any{
-				{"id": 1, "name": "apple", "description": "APPLE"},
-				{"id": 2, "name": "banana", "description": "BANANA"},
-			}, res)
+				// The trigger has been dropped.
+				triggerName := migrations.TriggerName("products", "description")
+				TriggerMustNotExist(t, db, schema, "products", triggerName)
+			},
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+				// after rollback + restart + complete, all 'description' values are the backfilled ones.
+				res := MustSelect(t, db, schema, "02_add_column", "products")
+				assert.Equal(t, []map[string]any{
+					{"id": "a", "name": "apple", "description": "APPLE"},
+					{"id": "b", "name": "banana", "description": "BANANA"},
+				}, res)
 
-			// The trigger function has been dropped.
-			triggerFnName := migrations.TriggerFunctionName("products", "description")
-			FunctionMustNotExist(t, db, "public", triggerFnName)
+				// The trigger function has been dropped.
+				triggerFnName := migrations.TriggerFunctionName("products", "description")
+				FunctionMustNotExist(t, db, schema, triggerFnName)
 
-			// The trigger has been dropped.
-			triggerName := migrations.TriggerName("products", "description")
-			TriggerMustNotExist(t, db, "public", "products", triggerName)
+				// The trigger has been dropped.
+				triggerName := migrations.TriggerName("products", "description")
+				TriggerMustNotExist(t, db, schema, "products", triggerName)
+			},
 		},
-	}})
+	})
 }
 
 func TestAddNotNullColumnWithNoDefault(t *testing.T) {
@@ -419,14 +507,14 @@ func TestAddNotNullColumnWithNoDefault(t *testing.T) {
 						Name: "products",
 						Columns: []migrations.Column{
 							{
-								Name:       "id",
-								Type:       "serial",
-								PrimaryKey: true,
+								Name: "id",
+								Type: "serial",
+								Pk:   ptr(true),
 							},
 							{
 								Name:   "name",
 								Type:   "varchar(255)",
-								Unique: true,
+								Unique: ptr(true),
 							},
 						},
 					},
@@ -441,36 +529,36 @@ func TestAddNotNullColumnWithNoDefault(t *testing.T) {
 						Column: migrations.Column{
 							Name:     "description",
 							Type:     "varchar(255)",
-							Nullable: false,
+							Nullable: ptr(false),
 						},
 					},
 				},
 			},
 		},
-		afterStart: func(t *testing.T, db *sql.DB) {
+		afterStart: func(t *testing.T, db *sql.DB, schema string) {
 			// Inserting a null description through the old view works (due to `up` sql populating the column).
-			MustInsert(t, db, "public", "01_add_table", "products", map[string]string{
+			MustInsert(t, db, schema, "01_add_table", "products", map[string]string{
 				"name": "apple",
 			})
 			// Inserting a null description through the new view fails.
-			MustNotInsert(t, db, "public", "02_add_column", "products", map[string]string{
+			MustNotInsert(t, db, schema, "02_add_column", "products", map[string]string{
 				"name": "banana",
-			})
+			}, testutils.CheckViolationErrorCode)
 		},
-		afterRollback: func(t *testing.T, db *sql.DB) {
+		afterRollback: func(t *testing.T, db *sql.DB, schema string) {
 			// the check constraint has been dropped.
 			constraintName := migrations.NotNullConstraintName("description")
-			ConstraintMustNotExist(t, db, "public", "products", constraintName)
+			CheckConstraintMustNotExist(t, db, schema, "products", constraintName)
 		},
-		afterComplete: func(t *testing.T, db *sql.DB) {
+		afterComplete: func(t *testing.T, db *sql.DB, schema string) {
 			// the check constraint has been dropped.
 			constraintName := migrations.NotNullConstraintName("description")
-			ConstraintMustNotExist(t, db, "public", "products", constraintName)
+			CheckConstraintMustNotExist(t, db, schema, "products", constraintName)
 
 			// can't insert a null description into the new view; the column now has a NOT NULL constraint.
-			MustNotInsert(t, db, "public", "02_add_column", "products", map[string]string{
+			MustNotInsert(t, db, schema, "02_add_column", "products", map[string]string{
 				"name": "orange",
-			})
+			}, testutils.NotNullViolationErrorCode)
 		},
 	}})
 }
@@ -485,14 +573,14 @@ func TestAddColumnValidation(t *testing.T) {
 				Name: "users",
 				Columns: []migrations.Column{
 					{
-						Name:       "id",
-						Type:       "serial",
-						PrimaryKey: true,
+						Name: "id",
+						Type: "serial",
+						Pk:   ptr(true),
 					},
 					{
 						Name:   "name",
 						Type:   "varchar(255)",
-						Unique: true,
+						Unique: ptr(true),
 					},
 				},
 			},
@@ -512,7 +600,7 @@ func TestAddColumnValidation(t *testing.T) {
 							Column: migrations.Column{
 								Name:     "age",
 								Type:     "integer",
-								Nullable: false,
+								Nullable: ptr(false),
 								Default:  ptr("0"),
 							},
 						},
@@ -552,7 +640,7 @@ func TestAddColumnValidation(t *testing.T) {
 							Column: migrations.Column{
 								Name:     "age",
 								Type:     "integer",
-								Nullable: false,
+								Nullable: ptr(false),
 							},
 						},
 					},
@@ -604,14 +692,14 @@ func TestAddColumnWithCheckConstraint(t *testing.T) {
 						Name: "users",
 						Columns: []migrations.Column{
 							{
-								Name:       "id",
-								Type:       "serial",
-								PrimaryKey: true,
+								Name: "id",
+								Type: "serial",
+								Pk:   ptr(true),
 							},
 							{
 								Name:   "name",
 								Type:   "varchar(255)",
-								Unique: true,
+								Unique: ptr(true),
 							},
 						},
 					},
@@ -635,33 +723,89 @@ func TestAddColumnWithCheckConstraint(t *testing.T) {
 				},
 			},
 		},
-		afterStart: func(t *testing.T, db *sql.DB) {
+		afterStart: func(t *testing.T, db *sql.DB, schema string) {
 			// Inserting a row that meets the constraint into the new view succeeds.
-			MustInsert(t, db, "public", "02_add_column", "users", map[string]string{
+			MustInsert(t, db, schema, "02_add_column", "users", map[string]string{
 				"name": "alice",
 				"age":  "30",
 			})
 
 			// Inserting a row that does not meet the constraint into the new view fails.
-			MustNotInsert(t, db, "public", "02_add_column", "users", map[string]string{
+			MustNotInsert(t, db, schema, "02_add_column", "users", map[string]string{
 				"name": "bob",
 				"age":  "3",
-			})
+			}, testutils.CheckViolationErrorCode)
 		},
-		afterRollback: func(t *testing.T, db *sql.DB) {
+		afterRollback: func(t *testing.T, db *sql.DB, schema string) {
 		},
-		afterComplete: func(t *testing.T, db *sql.DB) {
+		afterComplete: func(t *testing.T, db *sql.DB, schema string) {
 			// Inserting a row that meets the constraint into the new view succeeds.
-			MustInsert(t, db, "public", "02_add_column", "users", map[string]string{
+			MustInsert(t, db, schema, "02_add_column", "users", map[string]string{
 				"name": "carl",
 				"age":  "30",
 			})
 
 			// Inserting a row that does not meet the constraint into the new view fails.
-			MustNotInsert(t, db, "public", "02_add_column", "users", map[string]string{
+			MustNotInsert(t, db, schema, "02_add_column", "users", map[string]string{
 				"name": "dana",
 				"age":  "3",
-			})
+			}, testutils.CheckViolationErrorCode)
+		},
+	}})
+}
+
+func TestAddColumnWithComment(t *testing.T) {
+	t.Parallel()
+
+	ExecuteTests(t, TestCases{{
+		name: "add column",
+		migrations: []migrations.Migration{
+			{
+				Name: "01_add_table",
+				Operations: migrations.Operations{
+					&migrations.OpCreateTable{
+						Name: "users",
+						Columns: []migrations.Column{
+							{
+								Name: "id",
+								Type: "serial",
+								Pk:   ptr(true),
+							},
+							{
+								Name:   "name",
+								Type:   "varchar(255)",
+								Unique: ptr(true),
+							},
+						},
+					},
+				},
+			},
+			{
+				Name: "02_add_column",
+				Operations: migrations.Operations{
+					&migrations.OpAddColumn{
+						Table: "users",
+						Column: migrations.Column{
+							Name:     "age",
+							Type:     "integer",
+							Nullable: ptr(false),
+							Default:  ptr("0"),
+							Comment:  ptr("the age of the user"),
+						},
+					},
+				},
+			},
+		},
+		afterStart: func(t *testing.T, db *sql.DB, schema string) {
+			// The comment has been added to the underlying column.
+			columnName := migrations.TemporaryName("age")
+			ColumnMustHaveComment(t, db, schema, "users", columnName, "the age of the user")
+		},
+		afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+		},
+		afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+			// The comment is still present on the underlying column.
+			ColumnMustHaveComment(t, db, schema, "users", "age", "the age of the user")
 		},
 	}})
 }
