@@ -12,12 +12,6 @@ import (
 	"github.com/xataio/pgroll/pkg/schema"
 )
 
-type OpCreateIndex struct {
-	Name    string   `json:"name"`
-	Table   string   `json:"table"`
-	Columns []string `json:"columns"`
-}
-
 var _ Operation = (*OpCreateIndex)(nil)
 
 func (o *OpCreateIndex) Start(ctx context.Context, conn *sql.DB, stateSchema string, s *schema.Schema, cbs ...CallbackFn) error {
@@ -29,7 +23,7 @@ func (o *OpCreateIndex) Start(ctx context.Context, conn *sql.DB, stateSchema str
 	return err
 }
 
-func (o *OpCreateIndex) Complete(ctx context.Context, conn *sql.DB) error {
+func (o *OpCreateIndex) Complete(ctx context.Context, conn *sql.DB, s *schema.Schema) error {
 	// No-op
 	return nil
 }
