@@ -13,22 +13,6 @@ import (
 
 var _ Operation = (*OpCreateTable)(nil)
 
-type OpCreateTable struct {
-	Name    string   `json:"name"`
-	Columns []Column `json:"columns"`
-}
-
-type Column struct {
-	Name       string               `json:"name"`
-	Type       string               `json:"type"`
-	Nullable   bool                 `json:"nullable"`
-	Unique     bool                 `json:"unique"`
-	PrimaryKey bool                 `json:"pk"`
-	Default    *string              `json:"default"`
-	Check      *CheckConstraint     `json:"check"`
-	References *ForeignKeyReference `json:"references"`
-}
-
 func (o *OpCreateTable) Start(ctx context.Context, conn *sql.DB, stateSchema string, s *schema.Schema, cbs ...CallbackFn) error {
 	tempName := TemporaryName(o.Name)
 	_, err := conn.ExecContext(ctx, fmt.Sprintf("CREATE TABLE %s (%s)",
@@ -38,6 +22,22 @@ func (o *OpCreateTable) Start(ctx context.Context, conn *sql.DB, stateSchema str
 		return err
 	}
 
+	// Add comments to any columns that have them
+	for _, col := range o.Columns {
+		if col.Comment != nil {
+			if err := addCommentToColumn(ctx, conn, tempName, col.Name, *col.Comment); err != nil {
+				return fmt.Errorf("failed to add comment to column: %w", err)
+			}
+		}
+	}
+
+	// Add comment to the table itself
+	if o.Comment != nil {
+		if err := addCommentToTable(ctx, conn, tempName, *o.Comment); err != nil {
+			return fmt.Errorf("failed to add comment to table: %w", err)
+		}
+	}
+
 	columns := make(map[string]schema.Column, len(o.Columns))
 	for _, col := range o.Columns {
 		columns[col.Name] = schema.Column{
@@ -53,7 +53,7 @@ func (o *OpCreateTable) Start(ctx context.Context, conn *sql.DB, stateSchema str
 	return nil
 }
 
-func (o *OpCreateTable) Complete(ctx context.Context, conn *sql.DB) error {
+func (o *OpCreateTable) Complete(ctx context.Context, conn *sql.DB, s *schema.Schema) error {
 	tempName := TemporaryName(o.Name)
 	_, err := conn.ExecContext(ctx, fmt.Sprintf("ALTER TABLE IF EXISTS %s RENAME TO %s",
 		pq.QuoteIdentifier(tempName),
@@ -117,17 +117,17 @@ func columnsToSQL(cols []Column) string {
 func ColumnToSQL(col Column) string {
 	sql := fmt.Sprintf("%s %s", pq.QuoteIdentifier(col.Name), col.Type)
 
-	if col.PrimaryKey {
+	if col.IsPrimaryKey() {
 		sql += " PRIMARY KEY"
 	}
-	if col.Unique {
+	if col.IsUnique() {
 		sql += " UNIQUE"
 	}
-	if !col.Nullable {
+	if !col.IsNullable() {
 		sql += " NOT NULL"
 	}
 	if col.Default != nil {
-		sql += fmt.Sprintf(" DEFAULT %s", pq.QuoteLiteral(*col.Default))
+		sql += fmt.Sprintf(" DEFAULT %s", *col.Default)
 	}
 	if col.References != nil {
 		sql += fmt.Sprintf(" CONSTRAINT %s REFERENCES %s(%s)",
