@@ -11,12 +11,6 @@ import (
 	"github.com/xataio/pgroll/pkg/schema"
 )
 
-type OpDropColumn struct {
-	Table  string  `json:"table"`
-	Column string  `json:"column"`
-	Down   *string `json:"down,omitempty"`
-}
-
 var _ Operation = (*OpDropColumn)(nil)
 
 func (o *OpDropColumn) Start(ctx context.Context, conn *sql.DB, stateSchema string, s *schema.Schema, cbs ...CallbackFn) error {
@@ -40,8 +34,10 @@ func (o *OpDropColumn) Start(ctx context.Context, conn *sql.DB, stateSchema stri
 	return nil
 }
 
-func (o *OpDropColumn) Complete(ctx context.Context, conn *sql.DB) error {
-	_, err := conn.ExecContext(ctx, fmt.Sprintf("ALTER TABLE %s DROP COLUMN %s", o.Table, o.Column))
+func (o *OpDropColumn) Complete(ctx context.Context, conn *sql.DB, s *schema.Schema) error {
+	_, err := conn.ExecContext(ctx, fmt.Sprintf("ALTER TABLE %s DROP COLUMN %s",
+		pq.QuoteIdentifier(o.Table),
+		pq.QuoteIdentifier(o.Column)))
 	if err != nil {
 		return err
 	}
