@@ -10,10 +10,6 @@ import (
 	"github.com/xataio/pgroll/pkg/schema"
 )
 
-type OpDropIndex struct {
-	Name string `json:"name"`
-}
-
 var _ Operation = (*OpDropIndex)(nil)
 
 func (o *OpDropIndex) Start(ctx context.Context, conn *sql.DB, stateSchema string, s *schema.Schema, cbs ...CallbackFn) error {
@@ -21,7 +17,7 @@ func (o *OpDropIndex) Start(ctx context.Context, conn *sql.DB, stateSchema strin
 	return nil
 }
 
-func (o *OpDropIndex) Complete(ctx context.Context, conn *sql.DB) error {
+func (o *OpDropIndex) Complete(ctx context.Context, conn *sql.DB, s *schema.Schema) error {
 	// drop the index concurrently
 	_, err := conn.ExecContext(ctx, fmt.Sprintf("DROP INDEX CONCURRENTLY IF EXISTS %s", o.Name))
 
