@@ -11,11 +11,6 @@ import (
 
 var _ Operation = (*OpRawSQL)(nil)
 
-type OpRawSQL struct {
-	Up   string `json:"up"`
-	Down string `json:"down,omitempty"`
-}
-
 func (o *OpRawSQL) Start(ctx context.Context, conn *sql.DB, stateSchema string, s *schema.Schema, cbs ...CallbackFn) error {
 	_, err := conn.ExecContext(ctx, o.Up)
 	if err != nil {
@@ -24,7 +19,7 @@ func (o *OpRawSQL) Start(ctx context.Context, conn *sql.DB, stateSchema string,
 	return nil
 }
 
-func (o *OpRawSQL) Complete(ctx context.Context, conn *sql.DB) error {
+func (o *OpRawSQL) Complete(ctx context.Context, conn *sql.DB, s *schema.Schema) error {
 	return nil
 }
 
