@@ -25,7 +25,8 @@ func (o *OpSetNotNull) Start(ctx context.Context, conn *sql.DB, stateSchema stri
 	column := table.GetColumn(o.Column)
 
 	// Create a copy of the column on the underlying table.
-	if err := duplicateColumn(ctx, conn, table, *column); err != nil {
+	d := NewColumnDuplicator(conn, table, column)
+	if err := d.Duplicate(ctx); err != nil {
 		return fmt.Errorf("failed to duplicate column: %w", err)
 	}
 
@@ -34,7 +35,7 @@ func (o *OpSetNotNull) Start(ctx context.Context, conn *sql.DB, stateSchema stri
 		return fmt.Errorf("failed to add not null constraint: %w", err)
 	}
 
-	// Add a trigger to copy values from the old column to the new, rewriting NULL values using the `up` SQL.
+	// Add a trigger to copy values from the old column to the new, rewriting values using the `up` SQL.
 	err := createTrigger(ctx, conn, triggerConfig{
 		Name:           TriggerName(o.Table, o.Column),
 		Direction:      TriggerDirectionUp,
@@ -79,7 +80,7 @@ func (o *OpSetNotNull) Start(ctx context.Context, conn *sql.DB, stateSchema stri
 	return nil
 }
 
-func (o *OpSetNotNull) Complete(ctx context.Context, conn *sql.DB) error {
+func (o *OpSetNotNull) Complete(ctx context.Context, conn *sql.DB, s *schema.Schema) error {
 	// Validate the NOT NULL constraint on the old column.
 	// The constraint must be valid because:
 	// * Existing NULL values in the old column were rewritten using the `up` SQL during backfill.
@@ -130,11 +131,9 @@ func (o *OpSetNotNull) Complete(ctx context.Context, conn *sql.DB) error {
 	}
 
 	// Rename the new column to the old column name
-	_, err = conn.ExecContext(ctx, fmt.Sprintf("ALTER TABLE IF EXISTS %s RENAME COLUMN %s TO %s",
-		pq.QuoteIdentifier(o.Table),
-		pq.QuoteIdentifier(TemporaryName(o.Column)),
-		pq.QuoteIdentifier(o.Column)))
-	if err != nil {
+	table := s.GetTable(o.Table)
+	column := table.GetColumn(o.Column)
+	if err := RenameDuplicatedColumn(ctx, conn, table, column); err != nil {
 		return err
 	}
 
@@ -188,20 +187,3 @@ func (o *OpSetNotNull) downSQL() string {
 	}
 	return o.Down
 }
-
-func duplicateColumn(ctx context.Context, conn *sql.DB, table *schema.Table, column schema.Column) error {
-	column.Name = TemporaryName(column.Name)
-
-	_, err := conn.ExecContext(ctx, fmt.Sprintf("ALTER TABLE %s ADD COLUMN %s",
-		pq.QuoteIdentifier(table.Name),
-		schemaColumnToSQL(column),
-	))
-
-	return err
-}
-
-// TODO: This function needs to be able to duplicate a column more precisely
-// including constraints, indexes, defaults, etc.
-func schemaColumnToSQL(c schema.Column) string {
-	return fmt.Sprintf("%s %s", pq.QuoteIdentifier(c.Name), c.Type)
-}
