@@ -2,10 +2,6 @@
 
 package migrations
 
-type UniqueConstraint struct {
-	Name string `json:"name"`
-}
-
 func (c *UniqueConstraint) Validate() error {
 	if c.Name == "" {
 		return FieldRequiredError{Name: "name"}
