@@ -59,6 +59,11 @@ func (m *Roll) Start(ctx context.Context, migration *migrations.Migration, cbs .
 		}
 	}
 
+	if m.disableVersionSchemas {
+		// skip creating version schemas
+		return nil
+	}
+
 	// create schema for the new version
 	versionSchema := VersionedSchemaName(m.schema, migration.Name)
 	_, err = m.pgConn.ExecContext(ctx, fmt.Sprintf("CREATE SCHEMA IF NOT EXISTS %s", pq.QuoteIdentifier(versionSchema)))
@@ -86,21 +91,29 @@ func (m *Roll) Complete(ctx context.Context) error {
 	}
 
 	// Drop the old schema
-	prevVersion, err := m.state.PreviousVersion(ctx, m.schema)
-	if err != nil {
-		return fmt.Errorf("unable to get name of previous version: %w", err)
-	}
-	if prevVersion != nil {
-		versionSchema := VersionedSchemaName(m.schema, *prevVersion)
-		_, err = m.pgConn.ExecContext(ctx, fmt.Sprintf("DROP SCHEMA IF EXISTS %s CASCADE", pq.QuoteIdentifier(versionSchema)))
+	if !m.disableVersionSchemas {
+		prevVersion, err := m.state.PreviousVersion(ctx, m.schema)
 		if err != nil {
-			return fmt.Errorf("unable to drop previous version: %w", err)
+			return fmt.Errorf("unable to get name of previous version: %w", err)
 		}
+		if prevVersion != nil {
+			versionSchema := VersionedSchemaName(m.schema, *prevVersion)
+			_, err = m.pgConn.ExecContext(ctx, fmt.Sprintf("DROP SCHEMA IF EXISTS %s CASCADE", pq.QuoteIdentifier(versionSchema)))
+			if err != nil {
+				return fmt.Errorf("unable to drop previous version: %w", err)
+			}
+		}
+	}
+
+	// read the current schema
+	schema, err := m.state.ReadSchema(ctx, m.schema)
+	if err != nil {
+		return fmt.Errorf("unable to read schema: %w", err)
 	}
 
 	// execute operations
 	for _, op := range migration.Operations {
-		err := op.Complete(ctx, m.pgConn)
+		err := op.Complete(ctx, m.pgConn, schema)
 		if err != nil {
 			return fmt.Errorf("unable to execute complete operation: %w", err)
 		}
@@ -122,11 +135,13 @@ func (m *Roll) Rollback(ctx context.Context) error {
 		return fmt.Errorf("unable to get active migration: %w", err)
 	}
 
-	// delete the schema and view for the new version
-	versionSchema := VersionedSchemaName(m.schema, migration.Name)
-	_, err = m.pgConn.ExecContext(ctx, fmt.Sprintf("DROP SCHEMA IF EXISTS %s CASCADE", pq.QuoteIdentifier(versionSchema)))
-	if err != nil {
-		return err
+	if !m.disableVersionSchemas {
+		// delete the schema and view for the new version
+		versionSchema := VersionedSchemaName(m.schema, migration.Name)
+		_, err = m.pgConn.ExecContext(ctx, fmt.Sprintf("DROP SCHEMA IF EXISTS %s CASCADE", pq.QuoteIdentifier(versionSchema)))
+		if err != nil {
+			return err
+		}
 	}
 
 	// execute operations
@@ -147,16 +162,27 @@ func (m *Roll) Rollback(ctx context.Context) error {
 }
 
 // create view creates a view for the new version of the schema
-func (m *Roll) createView(ctx context.Context, version string, name string, table schema.Table) error {
+func (m *Roll) createView(ctx context.Context, version, name string, table schema.Table) error {
 	columns := make([]string, 0, len(table.Columns))
 	for k, v := range table.Columns {
 		columns = append(columns, fmt.Sprintf("%s AS %s", pq.QuoteIdentifier(v.Name), pq.QuoteIdentifier(k)))
 	}
 
+	// Create view with security_invoker option for PG 15+
+	//
+	// This ensures that any row level security permissions on the underlying
+	// table are respected. `security_invoker` views are not supported in PG 14
+	// and below.
+	withOptions := ""
+	if m.PGVersion() >= PGVersion15 {
+		withOptions = "WITH (security_invoker = true)"
+	}
+
 	_, err := m.pgConn.ExecContext(ctx,
-		fmt.Sprintf("CREATE OR REPLACE VIEW %s.%s AS SELECT %s FROM %s",
+		fmt.Sprintf("CREATE OR REPLACE VIEW %s.%s %s AS SELECT %s FROM %s",
 			pq.QuoteIdentifier(VersionedSchemaName(m.schema, version)),
 			pq.QuoteIdentifier(name),
+			withOptions,
 			strings.Join(columns, ","),
 			pq.QuoteIdentifier(table.Name)))
 	if err != nil {
